# Tutorials

[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://gishub.org/leafmap-colab)
[![image](https://mybinder.org/badge_logo.svg)](https://gishub.org/leafmap-binder)
[![image](https://mybinder.org/badge_logo.svg)](https://gishub.org/leafmap-binder)

1. Introducing the leafmap Python package for interactive mapping ([video](https://youtu.be/-UPt7x3Gn60) | [gif](https://i.imgur.com/2pRxunR.gif) | [notebook](https://leafmap.org/notebooks/01_leafmap_intro))
2. Using basemaps in leafmap ([video](https://youtu.be/uylpjbDZesY) | [gif](https://youtu.be/-lOo-vxjrDM) | [notebook](https://leafmap.org/notebooks/02_using_basemaps))
3. Using Cloud Optimized GeoTIFF (COG) and SpatioTemporal Asset Catalog (STAC) ([notebook](https://leafmap.org/notebooks/03_cog_stac))
4. Creating a virtual mosaic of Cloud Optimized GeoTIFFs (COG) ([notebook](https://leafmap.org/notebooks/04_cog_mosaic))
5. Loading local raster datasets with leafmap ([notebook](https://leafmap.org/notebooks/05_load_raster))
6. Adding custom legends to the map ([notebook](https://leafmap.org/notebooks/06_legend))
7. Adding custom colorbars to the map ([notebook](https://leafmap.org/notebooks/07_colorbar))
8. Using WhiteboxTools with leafmap ([notebook](https://leafmap.org/notebooks/08_whitebox))
9. Converting CSV to points ([notebook](https://leafmap.org/notebooks/09_csv_to_points))
10. Adding local vector data (e.g., shp, geojson, kml) to the map ([notebook](https://leafmap.org/notebooks/10_add_vector))
11. Creating linked maps for visualizing multiple maps simultaneously ([notebook](https://leafmap.org/notebooks/11_linked_maps))
12. Creating a split-panel map with only one line of code ([notebook](https://leafmap.org/notebooks/12_split_map))
13. Adding a GeoPandas GeoDataFrame to the map with a single line of code ([notebook](https://leafmap.org/notebooks/13_geopandas/))
14. Adding data from a PostGIS database to the map ([notebook](https://leafmap.org/notebooks/14_postgis))
15. Downloading OpenStreetMap data with a single line of code ([notebook](https://leafmap.org/notebooks/15_openstreetmap))
16. Using [HERE Map Widget for Jupyter](https://github.com/heremaps/here-map-widget-for-jupyter) as a plotting backend ([notebook](https://leafmap.org/notebooks/16_heremap))
17. Adding vector tile layers to the map ([notebook](https://leafmap.org/notebooks/17_vector_tile_layer))
18. Adding a point layer with popup attributes to the map ([notebook](https://leafmap.org/notebooks/18_point_layer))
19. Saving maps as a html file ([notebook](https://leafmap.org/notebooks/19_map_to_html))
20. Adding Planet global monthly and quarterly mosaic ([notebook](https://leafmap.org/notebooks/20_planet_imagery))
21. Using timeseries inspector with a single click ([notebook](https://leafmap.org/notebooks/21_ts_inspector))
22. Using time slider for visualizing timeseries images ([notebook](https://leafmap.org/notebooks/22_time_slider))
23. Creating colormaps with a single line of code ([notebook](https://leafmap.org/notebooks/23_colormaps))
24. Creating heat map from csv ([notebook](https://leafmap.org/notebooks/24_heatmap))
25. Creating a population heat map with a colorbar and map title ([notebook](https://leafmap.org/notebooks/25_map_title))
26. Creating an interactive map using the kepler.gl plotting backend ([notebook](https://leafmap.org/notebooks/26_kepler_gl))
27. Creating a basemap gallery ([notebook](https://leafmap.org/notebooks/27_basemap_gallery))
28. Publishing maps with a single line of code ([notebook](https://leafmap.org/notebooks/28_publish_map))
29. Using the pydeck plotting backend ([notebook](https://leafmap.org/notebooks/29_pydeck))
30. Using U.S. Census data ([notebook](https://leafmap.org/notebooks/30_census_data))
31. Searching basemaps with xyzservices ([notebook](https://leafmap.org/notebooks/31_search_basemaps))
32. Loading local raster datasets and Cloud Optimized GeoTIFF (COG) ([notebook](https://leafmap.org/notebooks/32_local_tile))
33. Adding image overlay to the map ([notebook](https://leafmap.org/notebooks/33_image_overlay))
34. Adding points from xy data (e.g., CSV, Pandas DataFrame) ([notebook](https://leafmap.org/notebooks/34_add_points_from_xy))
35. Adding circle markers from xy data (e.g., CSV, Pandas DataFrame) ([notebook](https://leafmap.org/notebooks/35_circle_markers))
36. Adding labels to the map ([notebook](https://leafmap.org/notebooks/36_add_labels))
37. Adding Planetary Computer STAC item to the map ([notebook](https://leafmap.org/notebooks/37_planetary_computer))
38. Using the plotly plotting backend ([notebook](https://leafmap.org/notebooks/38_plotly))
39. Getting pixel values using the Inspector tool ([notebook](https://leafmap.org/notebooks/39_inspector_tool))
40. Using the interactive plotly toolbar GUI ([notebook](https://leafmap.org/notebooks/40_plotly_gui))
41. Loading COG/STAC items using the raster GUI ([notebook](https://leafmap.org/notebooks/41_raster_gui))
42. Creating Cloud Optimized GeoTIFF (COG) ([notebook](https://leafmap.org/notebooks/42_create_cog))
43. Searching for locations and features in vector data ([notebook](https://leafmap.org/notebooks/43_search_control))
44. Opening vector data attribute table without coding ([notebook](https://leafmap.org/notebooks/44_attribute_table))
45. Creating vector data interactively without coding ([notebook](https://leafmap.org/notebooks/45_create_vector))
46. Editing existing vector data interactively without coding ([notebook](https://leafmap.org/notebooks/46_edit_vector))
47. Converting numpy array to COG ([notebook](https://leafmap.org/notebooks/47_numpy_to_cog))
48. Visualizing LiDAR data in 3D with only one line of code ([notebook](https://leafmap.org/notebooks/48_lidar))
49. Creating a split-panel map with folium ([notebook](https://leafmap.org/notebooks/49_split_control))
50. Creating a marker cluster with custom icons ([notebook](https://leafmap.org/notebooks/50_marker_cluster))
51. Clipping an image by mask ([notebook](https://leafmap.org/notebooks/51_clip_image))
52. Visualizing NetCDF data ([notebook](https://leafmap.org/notebooks/52_netcdf/))
53. Creating choropleth maps with a variety of classification schemes ([notebook](https://leafmap.org/notebooks/53_choropleth))
54. Plotting elevation data in 3D without only one line of code ([notebook](https://leafmap.org/notebooks/54_plot_raster))
55. LiDAR data analysis and visualization with whitebox and leafmap ([notebook](https://leafmap.org/notebooks/55_lidar))
56. Downloading 10-m National Elevation Dataset (NED) with only one line of code ([notebook](https://leafmap.org/notebooks/56_download_ned))
57. Creating interactive maps with bokeh ([notebook](https://leafmap.org/notebooks/58_bokeh))

## Demo

![](https://wetlands.io/file/images/leafmap_demo.gif)
